@@ -974,6 +974,11 @@ class Client(commandServer, encrypt, Desktop):
         self.umountRemoteUserRes(True,
                                  *self.clVars.Get('cl_client_user_mount_name'))
         return True
+    
+    def umountPath(self, upath):
+        if upath and not self.umountSleepPath(upath):
+            return False
+        return True
 
     def getDefaultRunlevelDaemons(self):
         """
