@@ -240,6 +240,12 @@ class ClClientSyncLoginAction(Action):
          'method': 'Client.setSyncStatus(ur_home_path,ur_uid,ur_gid,"error")',
          'depend': Tasks.hasnot('success_sync', 'failed')
          },
+        # отключить удалённый профиль
+        {'name': 'domain_sync:umount_unix',
+         'message': 'Umount {cl_client_user_mount_unix_path}',
+         'method': 'Client.umountPath(cl_client_user_mount_unix_path)',
+         'depend': Tasks.hasnot('failed')
+         },
         # отключить ресурсы в случае ошибки
         {'name': 'umount_remote_res',
          'message': __("Umounting user resources"),
@@ -279,6 +285,10 @@ class ClClientSyncLogoutAction(Action):
          'condition': lambda Get: path.exists(Get('ur_home_path')),
          'else_error': __("Home directory {ur_home_path} not found"),
          },
+        {'name': 'domain_user:mount_local',
+         'method': 'Client.mountUserDomainRes(ur_login,desktop.ur_password,'
+                   'ur_uid,ur_gid,"unix")',
+        },
         # проверить наличие подключенных ресурсов
         {'name': 'domain_user:check_mount',
          'condition': lambda Get: any(x and isMount(x)
